@@ -256,7 +256,14 @@ prsim.wave <- function(data, station_id="Qobs", number_sim=1, win_h_length=15,
     if(length(which(is.na(data[[l]]$index))>0)){
       data[[l]]$index[which(is.na(data[[l]]$index))] <- rep(c(1:365), times=length(unique(data[[l]]$YYYY)))[which(is.na(data[[l]]$index))]
     }
+    ### replace NA values by seasonal cycle as simulating series in the case of many NA values produces strange results
+    if(length(which(is.na(data[[l]]$Qobs)))>0){
+      cycle <- aggregate(data[[l]]$Qobs,by=list(data[[l]]$index),FUN=mean,na.rm=TRUE)
+      data_missing <- data[[l]][which(is.na(data[[l]]$Qobs)),]
+      data_missing$Qobs <- cycle$x[as.numeric(data_missing$index)]
+      data[[l]][which(is.na(data[[l]]$Qobs)),]$Qobs <- data_missing$Qobs
     }
+  }
    
   if (verbose) cat(paste0("Detrending with (half-)length ",win_h_length,"...\n"))  
 
